@@ -52,14 +52,18 @@ def parse(
     except ScannerError as err:
         if err.problem in ["found character '\\t' that cannot start any token", "found unknown escape character"]:
             try:
-                (template, template_lines) = json_parse(filename, allow_nulls=False)
+                result = json_parse(filename, allow_nulls=False)
+                if result:
+                    template, template_lines = result
             except Exception as json_err:  # pylint: disable=W0703
                 error = f"Template {filename} is malformed: {err.problem}. Tried to parse {filename} as JSON but got error: {json_err}"
                 LOGGER.info(error)
     except YAMLError as err:
         if hasattr(err, 'problem') and err.problem in ["expected ',' or '}', but got '<scalar>'"]:
             try:
-                (template, template_lines) = json_parse(filename, allow_nulls=False)
+                result = json_parse(filename, allow_nulls=False)
+                if result:
+                    template, template_lines = result
             except Exception as json_err:  # pylint: disable=W0703
                 error = f"Template {filename} is malformed: {err.problem}. Tried to parse {filename} as JSON but got error: {json_err}"
                 LOGGER.info(error)
