@@ -234,13 +234,16 @@ class Runner(ImageReferencerMixin, BaseRunner[CloudformationGraphManager]):
         return report
 
     def extract_images(
-        self, graph_connector: DiGraph | None = None, definitions: dict[str, dict[str, Any] | list[dict[str, Any]]] | None = None
+        self,
+        graph_connector: DiGraph | None = None,
+        definitions: dict[str, dict[str, Any] | list[dict[str, Any]]] | None = None,
+        definitions_raw: dict[str, list[tuple[int, str]]] | None = None
     ) -> list[Image]:
         if not graph_connector:
             # should not happen
             return []
 
         manager = CloudFormationImageReferencerManager(graph_connector=graph_connector)
-        images = manager.extract_images_from_resources()
+        images: list[Image] = manager.extract_images_from_resources()
 
         return images
