@@ -53,15 +53,17 @@ class DockerImageScanningIntegration(TwistcliIntegration):
         file_content: str,
         docker_image_name: str,
         related_resource_id: str | None = None,
+        root_folder: str | Path | None = None
     ) -> dict[str, Any]:
         if not bc_platform_integration.bc_source:
             logging.error("Source was not set")
             return {}
 
         results_dict = self._get_results_dict(twistcli_scan_result)
+        path_prefix = str(root_folder) if root_folder else os.getenv("BC_ROOT_DIR", "")
         payload: dict[str, Any] = {
             "dockerImageName": docker_image_name,
-            "dockerFilePath": removeprefix(str(file_path), os.getenv("BC_ROOT_DIR", "")),
+            "dockerFilePath": removeprefix(str(file_path), path_prefix),
             "dockerFileContent": file_content,
             "type": "Image",
             "sourceId": bc_platform_integration.repo_id,
