@@ -3,7 +3,7 @@ from __future__ import annotations
 import concurrent.futures
 import logging
 
-from typing import List, Dict, Any, TYPE_CHECKING
+from typing import Any, TYPE_CHECKING
 
 from checkov.common.models.enums import CheckResult
 from checkov.runner_filter import RunnerFilter
@@ -12,11 +12,12 @@ if TYPE_CHECKING:
     from networkx import DiGraph
     from checkov.common.graph.checks_infra.base_check import BaseGraphCheck
     from checkov.common.graph.checks_infra.base_parser import BaseGraphCheckParser
+    from checkov.common.typing import _CheckResult
 
 
 class BaseRegistry:
     def __init__(self, parser: BaseGraphCheckParser) -> None:
-        self.checks: List[BaseGraphCheck] = []
+        self.checks: "list[BaseGraphCheck]" = []
         self.parser = parser
 
     def load_checks(self) -> None:
@@ -24,9 +25,9 @@ class BaseRegistry:
 
     def run_checks(
         self, graph_connector: DiGraph, runner_filter: RunnerFilter, report_type: str
-    ) -> Dict[BaseGraphCheck, List[Dict[str, Any]]]:
+    ) -> dict[BaseGraphCheck, list[_CheckResult]]:
 
-        check_results: Dict[BaseGraphCheck, List[Dict[str, Any]]] = {}
+        check_results: "dict[BaseGraphCheck, list[_CheckResult]]" = {}
         checks_to_run = [c for c in self.checks if runner_filter.should_run_check(c, report_type=report_type)]
 
         with concurrent.futures.ThreadPoolExecutor() as executor:
@@ -37,7 +38,7 @@ class BaseRegistry:
         return check_results
 
     def run_check_parallel(
-        self, check: BaseGraphCheck, check_results: Dict[BaseGraphCheck, List[Dict[str, Any]]], graph_connector: DiGraph
+        self, check: BaseGraphCheck, check_results: dict[BaseGraphCheck, list[_CheckResult]], graph_connector: DiGraph
     ) -> None:
         logging.debug(f'Running graph check: {check.id}')
         passed, failed, unknown = check.run(graph_connector)
@@ -49,10 +50,11 @@ class BaseRegistry:
 
     @staticmethod
     def _process_check_result(
-        results: List[Dict[str, Any]],
-        processed_results: List[Dict[str, Any]],
-        result: CheckResult, evaluated_keys: List[str],
-    ) -> List[Dict[str, Any]]:
+        results: list[dict[str, Any]],
+        processed_results: list[_CheckResult],
+        result: CheckResult,
+        evaluated_keys: list[str],
+    ) -> list[_CheckResult]:
         for vertex in results:
             processed_results.append({"result": result, "entity": vertex, "evaluated_keys": evaluated_keys})
         return processed_results
