@@ -3,14 +3,14 @@ from checkov.common.models.enums import CheckCategories
 
 
 class DAXEncryption(BaseResourceValueCheck):
-    def __init__(self):
+    def __init__(self) -> None:
         name = "Ensure DAX is encrypted at rest (default is unencrypted)"
         id = "CKV_AWS_47"
-        supported_resources = ['aws_dax_cluster']
+        supported_resources = ["aws_dax_cluster"]
         categories = [CheckCategories.ENCRYPTION]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
-    def get_inspected_key(self):
+    def get_inspected_key(self) -> str:
         return "server_side_encryption/[0]/enabled"
 
 
