@@ -42,7 +42,7 @@ class DropCapabilities(BaseResourceCheck):
                     context = container.get("security_context")[0]
                     if context.get("capabilities") and isinstance(context.get("capabilities"), list):
                         capabilities = context.get("capabilities")[0]
-                        if capabilities.get("drop") and isinstance(capabilities.get("drop"), list):
+                        if isinstance(capabilities, dict) and capabilities.get("drop") and isinstance(capabilities.get("drop"), list):
                             drops = capabilities.get("drop")[0]
                             for drop in drops:
                                 if drop in ["ALL", "NET_RAW"]:
