@@ -8,12 +8,21 @@ class ReadonlyRootFilesystem(BaseResourceCheck):
         name = "Use read-only filesystem for containers where possible"
         id = "CKV_K8S_22"
 
-        supported_resources = ['kubernetes_pod', 'kubernetes_pod_v1']
+        supported_resources = ['kubernetes_pod', "kubernetes_pod_v1",
+                               'kubernetes_deployment', 'kubernetes_deployment_v1']
         categories = [CheckCategories.GENERAL_SECURITY]
         super().__init__(name=name, id=id, categories=categories, supported_resources=supported_resources)
 
     def scan_resource_conf(self, conf) -> CheckResult:
         spec = conf.get('spec', [None])[0]
+        evaluated_keys_path = "spec"
+
+        if spec.get("template") and isinstance(spec.get("template"), list):
+            template = spec.get("template")[0]
+            if template.get("spec") and isinstance(template.get("spec"), list):
+                spec = template.get("spec")[0]
+                evaluated_keys_path = f'{evaluated_keys_path}/[0]/template/[0]/spec'
+
         if isinstance(spec, dict) and spec.get("container"):
             containers = spec.get("container")
 
@@ -23,7 +32,7 @@ class ReadonlyRootFilesystem(BaseResourceCheck):
                 if container.get("security_context"):
                     context = container.get("security_context")[0]
                     if context.get("read_only_root_filesystem") != [True]:
-                        self.evaluated_keys = [f'spec/[0]/container/[{idx}]/security_context/[0]/read_only_root_filesystem']
+                        self.evaluated_keys = [f'{evaluated_keys_path}/[0]/container/[{idx}]/security_context/[0]/read_only_root_filesystem']
                         return CheckResult.FAILED
         return CheckResult.PASSED
 
